/*
******************************************************************************

   OVL implementation for X target - sprite helper functions

   Copyright (C) 2001	Christoph Egger	[Christoph_Egger@t-online.de]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <stdio.h>

#include "xovl.h"


#include <ggi/display/xcommon.h>
#include <ggi/display/x.h>

#include <X11/X.h>



int sprite_show(ggiOvl_t ovl)
{
	int rc = GALLOC_OK;


	switch (ovl->res_type & GA_RT_SUBTYPE_MASK) {
	case (GA_RT_SPRITE_DONTCARE & GA_RT_SUBTYPE_MASK):

		/* Oops! We know, X can handle kind of sprites:
		 * X-mouse-cursor-sprite and X-text-cursor-sprite.
		 * But nothing is specified to allocate, so we
		 * fail here.
		 */
		rc = GALLOC_EUNAVAILABLE;
		break;

	case (GA_RT_SPRITE_POINTER & GA_RT_SUBTYPE_MASK):
		{
		ggi_xwin_common *priv = NULL;
		struct xovl_Sprite *sprite = NULL;

		priv = LIBGGI_PRIVATE(ovl->vis);
		sprite = (struct xovl_Sprite *)ovl->Ovltype.sprite.target;

		XDefineCursor(priv->x.display,
			priv->window, sprite->sprite->cursor);
		}
		break;

	case (GA_RT_SPRITE_CURSOR & GA_RT_SUBTYPE_MASK):
		break;

	case (GA_RT_SPRITE_SPRITE & GA_RT_SUBTYPE_MASK):
		rc = GALLOC_EUNAVAILABLE;
		break;
	}	/* switch */

	return rc;
}	/* sprite_show */






int sprite_hide(ggiOvl_t ovl)
{
	int rc = GALLOC_OK;

	switch (ovl->res_type & GA_RT_SUBTYPE_MASK) {
	case (GA_RT_SPRITE_DONTCARE & GA_RT_SUBTYPE_MASK):

		/* Oops! We know, X can handle kind of sprites:
		 * X-mouse-cursor-sprite and X-text-cursor-sprite.
		 * But nothing is specified to allocate, so we
		 * fail here.
		 */
		rc = GALLOC_EUNAVAILABLE;
		break;

	case (GA_RT_SPRITE_POINTER & GA_RT_SUBTYPE_MASK):
		{
		ggi_xwin_common *priv = NULL;
		struct xovl_Sprite *sprite = NULL;

		priv = LIBGGI_PRIVATE(ovl->vis);
		sprite = (struct xovl_Sprite *)ovl->Ovltype.sprite.target;

		XUndefineCursor(priv->x.display, priv->window);
		}
		break;

	case (GA_RT_SPRITE_CURSOR & GA_RT_SUBTYPE_MASK):
		break;

	case (GA_RT_SPRITE_SPRITE & GA_RT_SUBTYPE_MASK):
		rc = GALLOC_EUNAVAILABLE;
		break;
	}	/* switch */

	return rc;
}	/* sprite_hide */
